@@ -8,18 +8,25 @@ setClass("mpfr1", ## a single Multi-precision float number
 	 representation(prec = "integer", # precision in bits
 			exp = "integer",  # exponent
 			sign= "integer",  # signum
-			d = "integer"),	  # the mantissa as a vector of long
+			d = "integer"),	  # the mantissa as a vector of (32 bit) integers
 	 validity = function(object) {
+	     gmp.numb <- .mpfr.gmp.numbbits() # 32 or 64
 	     if(length(pr <- object@prec) != 1 || is.na(pr) || pr < 2)
 		 "invalid 'prec' slot"
-	     else if(length(ex <- object@prec) != 1)
-		 "invalid 'exp' slot"
-	     else if(length(sig <- object@sign) != 1 || is.na(sig) ||
-		     abs(sig) > 1)
-		 "invalid 'sign' slot"
-	     else if(length(d <- object@d) != ceiling(pr / 32))
-		 "length('d' slot) does not match 'prec'"
-	     else TRUE
+	     else if((lex <- length(ex <- object@exp)) != 2 && gmp.numb == 64)
+		 "invalid 'exp' slot for 64-bit gmp.numbbits: must have length 2"
+	     else if(lex != 1 && gmp.numb == 32)
+		 "invalid 'exp' slot for 32-bit gmp.numbbits: must have length 1"
+	     else if(length(sig <- object@sign) != 1 || is.na(sig) || abs(sig) > 1)
+		 "'sign' slot not in {-1,1} is invalid"
+	     else {
+		 nd <- length(d <- object@d)
+		 need.d <- ceiling(pr / 32)
+		 if((gmp.numb == 32 && nd != need.d) ||
+		    (gmp.numb == 64 && !any((nd - need.d) == 0:1)))
+		     "length('d' slot) does not match 'prec'"
+		 else TRUE
+	     }
 	 })
 
 setClass("mpfr", ## a *vector* of "mpfr1", i.e., multi-precision float numbers
